"""Email sending functions"""

from gnatpython.ex import Run

import os


def sendmail(from_email, to_emails, mail_as_string, smtp_server,
             max_size=10):
    """Send an email with sendmail or stmplib

    PARAMETERS
      from_email: the address sending this email (e.g. user@example.com)
      to_emails: A list of addresses to send this email to.
      mail_as_string: the message to send (with headers)
      max_size: do not send the email via smptlib if bigger than 'max_size' Mo.

    RETURNS
      A boolean (sent / not sent)

    We prefer running sendmail over using smtplib because
    sendmail queues the email and retries a few times if
    the target server is unable to receive the email.
    """
    result = False
    for sendmail in ('/usr/lib/sendmail', '/usr/sbin/sendmail'):
        if os.path.exists(sendmail):
            p = Run([sendmail] + to_emails, input="|" +
                    mail_as_string, output=None)
            result = p.status == 0
            break

    if not result:
        if len(mail_as_string) / (1024 * 1024) >= max_size:
            # Message too big
            return False

        # Else try to use smtplib
        import smtplib
        s = smtplib.SMTP(smtp_server)
        if not s.sendmail(from_email, to_emails, mail_as_string):
            # sendmail returns an empty dictionary if the message
            # was accepted for delivery to all addresses
            result = True
        s.quit()
    return result
